Module log

Module log 

Structs

Log
A simple node that logs whatever value is received at a given log level.

Functions

log_target
The log target identifying the node at the given path, e.g. gantz:0:3:2.
parse_log_target
Parse the node path back out of a log_target-formatted target.